==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ron/messagemanager.php <==
<?php
/**
 * UTF8
 * stanislav.elbl, 29.07.2015
 */

namespace Ron;


use Exception;
use Ron\DB\Database;
use Ron\Http\App;

class MessageManager
{

    public static $TEXT_CLASSES = [
        Message::INFO => 'infomsg',
        Message::ERROR => 'errortext',
        Message::DEBUG => 'debugmsg',
        Message::WARNING => 'warningmsg',
        Message::SUCCESS => 'successmsg',
    ];

    public static $DESCRIPTION_CLASSES = [
        Message::INFO => '',
        Message::ERROR => 'errorinfo',
        Message::DEBUG => 'debugmsg',
        Message::WARNING => 'warningmsg',
        Message::SUCCESS => 'successmsg',
    ];

    /** @var  Message[] */
    protected $messages;

    /** @var  MessageManager $messageManager Globalni instance */
    protected static $messageManager;


    function __construct()
    {
        $this->messages = [];
    }


    function clear()
    {
        $this->messages = [];
    }


    /**
     * @return Message[]
     */
    public function getMessages()
    {
        return $this->messages;
    }


    /**
     * @param string $text
     * @param int $type
     * @param string $fieldName
     * @param string $id
     * @param string $description
     * @return Message
     */
    function addMessage($text, $type = Message::INFO, $fieldName = null, $id = null, $description = null)
    {
        $message = new Message($text, $type, $fieldName, $id, $description);
        $this->messages[] = $message;

        return $message;
    }


    /**
     * @param string $text
     * @param int $type
     * @param string $fieldName
     * @param string $id
     * @param string $description
     * @return Message
     */
    function addHtmlMessage($text, $type = Message::INFO, $fieldName = null, $id = null, $description = null)
    {
        $message = new Message($text, $type, $fieldName, $id, $description);
        $message ->isHtml = true;
        $this->messages[] = $message;

        return $message;
    }


    /**
     * Prida novou chybovou hlasku
     * @param string $text
     * @param string $fieldName
     * @param string $id
     * @param string $description
     * @return Message
     */
    function addError($text, $fieldName = null, $id = null, $description = null)
    {
        return $this->addMessage($text, Message::ERROR, $fieldName, $id, $description);
    }


    /**
     * Prida novou chybovou hlasku
     *
     * @param Database $database
     * @param string $sql
     * @param string $text
     * @param string $fieldName
     * @return Message
     */
    function addDbError($database, $sql = null, $text = null, $fieldName = null)
    {
        if (!$text) $text = 'Chyba v SQL dotazu!';

        $error = new Message($text,
            Message::ERROR, $fieldName, null,
            $database->lastErrorText() . "\n" . $sql);

        $this->messages[] = $error;

        return $error;
    }


    /**
     * Najde chybu pro zadane pole. Kdyz neni pole zadane, vraci prvni chybu, kterou najde.
     * @param string $fieldName
     * @return Message
     */
    function findError($fieldName = null)
    {
        foreach ($this->messages as $error) {
            if ($error->type == Message::ERROR && (!$fieldName || $error->fieldName == $fieldName)) {
                return $error;
            }
        }

        return null;
    }


    /**
     * Vraci true, pokud je pro zadane pole alespon jedna chyba. Kdyz neni pole zadane, vraci true pokud je jakakoliv chyba.
     * @param string $fieldName
     * @param bool $throwException Pokud je true, tak v pripade chyby vyhodi vyjimku
     * @return bool
     * @throws RonException
     */
    public function isError($fieldName = null, $throwException = false)
    {
        $error = $this ->findError($fieldName);
        if ($throwException  &&  $error) {
            throw new RonException($error->text, $error->fieldName, $error->description);
        }

        return (bool)$error;
    }


    /**
     * @param Message $message
     * @param int $index
     */
    public static function showMessage($message, $index = null)
    {
        if ($message->type === Message::LOG) {
            echo
                '<script>console.log("DEBUG>", ' .
                ($message->fieldName ? '"' . $message->fieldName . '", ' : '') .
                json_encode(StringUtils::jsonText($message->text, false)) . ');</script>';
        } else {

            $css = isset(self::$TEXT_CLASSES[$message->type]) ? self::$TEXT_CLASSES[$message->type] : null;
            echo
                '<div' . ($css ? " class='$css'" : '') .
                    ($message ->fieldName ? " data-ron-fieldname='{$message ->fieldName}'" : '') .
                    (isset($index) ? " data-ron-index='$index'" : '') .
                '>' .
                ($message ->isHtml ? $message ->text : StringUtils::htmlTextConvert($message->text)) .
                "</div>\n";

            if ($message->description) {
                $css = isset(self::$DESCRIPTION_CLASSES[$message->type]) ? self::$DESCRIPTION_CLASSES[$message->type] : null;
                echo '<div' . ($css ? " class='$css'" : '') . '>' . str_replace("\n", '<br/>', StringUtils::htmlTextConvert($message->description)) . "</div>\n";
            }
        }
        //errormsg($message->text, $message->description);
    }


    /**
     * Vraci prvni zpravu, ktera odpovida zadanym podminkam (fieldName a/nebo id)
     * @param string $fieldName
     * @param string $id
     * @return Message
     */
    public function findMessage($fieldName, $id = null)
    {
        foreach ($this->messages as $message) {
            if ((!$fieldName || $message->fieldName == $fieldName) && (!$id || $id == $message->id)) {
                return $message;
            }
        }

        return null;
    }


    /**
     * Zobrazi zpravy pro zadane pole (nebo vsechny, pokud neni zadano), typ a/nebo id.
     * Vraci pocet zobrazenych zprav.
     * @param string|null $fieldname
     * @param string|null $type
     * @param string|null $id
     * @return int
     */
    public function showMessages($fieldname = null, $type = null, $id = null)
    {
        $index = 0;

        echo '<div class="errormessages">';
        foreach ($this->messages as $message) {
            if (!$fieldname || $message->fieldName == $fieldname) {
                if (!$type || $message->type == $type) {
                    if (!$id || $message->id == $id) {
                        self::showMessage($message, $index);
                        $index++;
                    }
                }
            }
        }
        echo "</div>\n";

        return $index;
    }

    /**
     * Zobrazi chyby pro zadane pole (nebo vsechny, pokud neni zadano).
     * V pripade, ze byla zobrazena alespon jedna chyba vraci false, jinak true
     * @param string|null $fieldname
     * @param string|null $id
     * @return boolean
     */
    function showErrors($fieldname = null, $id = null)
    {
        $cnt = $this->showMessages($fieldname, Message::ERROR, $id);
        return !$cnt;
    }


    public function errorsDialog($htmlId)
    {
        try {
            if (!$this->isError()) {
                return true;
            }
        } catch (RonException $e) {
            echo 'CHYBA v MessageManager::errorsDialog! ' . $e ->getMessage();
        }

        echo "<div class='errorsdialog' id='$htmlId'>";

        foreach ($this->messages as $error) {
            if ($error->type === Message::ERROR) {
                self::showMessage($error);
                //errormsg($error->text, $error->description);
            }
        }

        echo "</div>";

        echo '<script>$( function() { ron.errorsDialog("#' . $htmlId . '")})</script>';
        return false;

    }


    public function storeToSession()
    {
        $array = [];

        foreach ($this->messages as $message) {
            $array[] = $message->storeToArray();
        }

        $_SESSION['Ron.MessageManager.Messages'] = $array;
    }


    protected function loadFromSession()
    {
        $array = isset($_SESSION['Ron.MessageManager.Messages']) ? $_SESSION['Ron.MessageManager.Messages'] : null;

        if ($array) {
            foreach ($array as $msgArray) {
                $message = new Message(Message::INFO);
                $message->loadFromAray($msgArray);

                $this->messages[] = $message;
            }

            unset($_SESSION['Ron.MessageManager.Messages']);
        }
    }


    /**
     * Vraci globalni instanci objektu MessageManager
     * @param bool $loadFromSession urcuje, jestli se maji nacist zpravy predane pres session (pouziva se v redirect)
     * @return MessageManager
     */
    public static function getInstance($loadFromSession = true)
    {
        if (!self::$messageManager) {
            self::$messageManager = new MessageManager();

            if ($loadFromSession) {
                self::$messageManager->loadFromSession();
            }
        }

        return self::$messageManager;
    }

    /**
     * @param string $text
     */
    public static function addInfoMessage($text)
    {
        self::getInstance()->addMessage($text);
    }


    /**
     * @param string $text
     */
    public static function addSuccessMessage($text)
    {
        self::getInstance()->addMessage($text, Message::SUCCESS);
    }


    /**
     * @param string|Exception|RonException $text
     * @param string $fieldName
     * @param string $id
     * @param string $description
     * @return bool
     */
    public static function addErrorMessage($text, $fieldName = null, $id = null, $description = null)
    {
        if ($text instanceof RonException) {
            if (!$fieldName) {
                $fieldName = $text ->fieldName;
            }
            $text = $text ->getMessage();
        } else if ($text instanceof Exception) {
            if (!App::getDebugMode()) {
                $text = $text->getMessage();
            }
        }

        self::getInstance()->addError($text, $fieldName, $id, $description);
        return false;
    }


    /**
     * Prida chybovou hlasku, kterou nejdrive prelozi pomoci ronText
     * @param string $textId Kod textu pro preklad
     * @param string $fieldName
     * @param string $id
     * @param string $description
     * @return bool
     */
    public static function addErrorText($textId, $fieldName = null, $id = null, $description = null)
    {
        self::getInstance()->addError(ronText($textId), $fieldName, $id, $description);
        return false;
    }

    /**
     * Prida novou databazovou chybovou hlasku
     * @param Database $database
     * @param string $sql
     * @param string $text
     * @param string $fieldName
     * @return bool
     */
    public static function addDbErrorMessage($database, $sql = null, $text = null, $fieldName = null)
    {
        self::getInstance()->addDbError($database, $sql, $text, $fieldName);
        return false;
    }

    /**
     * @param $text
     * @return null|Message
     */
    public static function addDebugMessage($text)
    {
        if (App::getDebugMode()) {
            return self::getInstance()->addMessage($text, Message::DEBUG);
        }

        return null;
    }

    /**
     * @param $text
     * @param null $fieldName
     * @return null|Message
     */
    public static function addDebugLog($text, $fieldName = null)
    {
        if (App::getDebugMode()) {
            return self::getInstance()->addMessage($text, Message::LOG, $fieldName);
        }

        return null;
    }


    /**
     * Prida hlasku do console.
     * @param string $text
     * @return Message
     */
    public static function addLogMessage($text)
    {
        return self::getInstance()->addMessage($text, Message::LOG);
    }


    public static function debugPost()
    {
        if (App::getDebugMode()) {
            $text = "POST:\n";
            if (is_array($_POST)) {
                foreach ($_POST as $name => $value) {
                    $text .= $name . '=' . $value . "\n";
                }
            }

            return self::addDebugLog($text);
        }

        return null;
    }


    public static function addWarning($text, $fieldName = null)
    {
        self::getInstance()->addMessage($text, Message::WARNING, $fieldName);
    }


    /**
     * Zjisti, jestli existuje nejaka zprava pro zadane pole a podle toho vraci nazev css tridy
     * @param string $fieldName
     * @param string $defaultValue
     * @return string
     */
    public static function getClass($fieldName, $defaultValue = '')
    {
        $result = $defaultValue;

        $mgr = self::getInstance();
        foreach ($mgr->messages as $message) {
            if ($message->fieldName === $fieldName) {
                switch ($message->type) {
                    case Message::ERROR :
                        return 'error';

                    case Message::WARNING :
                        $result = 'warning';
                }
            }
        }

        return $result;
    }

    /**
     * Zjisti, jestli existuje nejaka zprava pro zadane pole a podle toho vraci html kod class="..."
     * @param string $fieldName
     * @param string $defaultClass
     * @return string
     */
    public static function getClassHtml($fieldName, $defaultClass = '')
    {
        $className = self::getClass($fieldName, $defaultClass);
        if ($className) {
            return 'class="' . $className . '"';
        }

        return '';
    }


    /**
     * Zjisti, jestli existuje nejaka zprava pro zadane pole a podle toho vraci title (text chyby)
     * @param string $fieldName
     * @param string $defaultValue
     * @return string
     */
    public static function getTitle($fieldName, $defaultValue = '')
    {
        $result = $defaultValue;

        $mgr = self::getInstance();
        foreach ($mgr->messages as $message) {
            if ($message->fieldName === $fieldName) {
                switch ($message->type) {
                    case Message::ERROR :
                        return $message ->text;

                    case Message::WARNING :
                        $result = $message ->text;
                }
            }
        }

        return $result;
    }


    public static function getTitleHtml($fieldName, $defaultValue = '')
    {
        $title = self::getTitle($fieldName, $defaultValue);
        if ($title) {
            return 'title="' . StringUtils::htmlTextConvert($title) . '"';
        }

        return '';
    }

}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/ron/messagemanager.php <==
<?php
/**
 * stanislav.elbl, 29.07.2015
 */

namespace Ron;


use Exception;
use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\Http\App;

class MessageManager
{

    public static $TEXT_CLASSES = [
        Message::INFO => 'infomsg',
        Message::ERROR => 'errortext',
        Message::DEBUG => 'debugmsg',
        Message::WARNING => 'warningmsg',
        Message::SUCCESS => 'successmsg',
    ];

    public static $DESCRIPTION_CLASSES = [
        Message::INFO => '',
        Message::ERROR => 'errorinfo',
        Message::DEBUG => 'debugmsg',
        Message::WARNING => 'warningmsg',
        Message::SUCCESS => 'successmsg',
    ];

    /** @var  Message[] */
    protected $messages;

    /** @var  Message[]     Pomocne pole zprav, ktere maji ID */
    protected $messagesById = [];

    /** @var  MessageManager $messageManager Globalni instance */
    protected static $messageManager;


    function __construct()
    {
        $this->messages = [];
    }


    function clear()
    {
        $this->messages = [];
    }


    /**
     * @return Message[]
     */
    public function getMessages()
    {
        return $this->messages;
    }


    /**
     * @param Message $message
     */
    private function addNewMessage($message)
    {
        if ($message ->id  &&  isset($this ->messagesById[$message ->id])) {
            // zprava se stejnym ID uz existuje => nepridava ji
            return;
        }

        $this ->messages[] = $message;

        if ($message ->id) {
            $this ->messagesById[$message ->id] = $message;
        }
    }


    /**
     * @param string $text
     * @param int $type
     * @param string $fieldName
     * @param string $id
     * @param string $description
     * @return Message
     */
    function addMessage($text, $type = Message::INFO, $fieldName = null, $id = null, $description = null)
    {
        $message = new Message($text, $type, $fieldName, $id, $description);
        $this ->addNewMessage($message);

        return $message;
    }


    /**
     * @param string $text
     * @param int $type
     * @param string $fieldName
    e * @param string $id
     * @param string $description
     * @return Message
     */
    function addHtmlMessage($text, $type = Message::INFO, $fieldName = null, $id = null, $description = null)
    {
        $message = new Message($text, $type, $fieldName, $id, $description);
        $message ->isHtml = true;

        $this ->addNewMessage($message);

        return $message;
    }


    /**
     * Prida novou chybovou hlasku
     * @param string $text
     * @param string $fieldName
     * @param string $id
     * @param string $description
     * @return Message
     */
    function addError($text, $fieldName = null, $id = null, $description = null)
    {
        return $this->addMessage($text, Message::ERROR, $fieldName, $id, $description);
    }


    /**
     * Prida novou chybovou hlasku
     *
     * @param Database $database
     * @param string $sql
     * @param string $text
     * @param string $fieldName
     * @return Message
     */
    function addDbError($database, $sql = null, $text = null, $fieldName = null)
    {
        if (!$text) {
            $text = 'V aplikaci doslo k chybe!';
        }

        $error = new Message($text,
            Message::ERROR, $fieldName, null,
            $database->lastErrorText() . "\n" . $sql);

        $this ->addNewMessage($error);

        return $error;
    }


    /**
     * Najde chybu pro zadane pole. Kdyz neni pole zadane, vraci prvni chybu, kterou najde.
     * @param string $fieldName
     * @return Message
     */
    function findError($fieldName = null)
    {
        foreach ($this->messages as $error) {
            if ($error->type == Message::ERROR && (!$fieldName || $error->fieldName == $fieldName)) {
                return $error;
            }
        }

        return null;
    }


    /**
     * Vraci true, pokud je pro zadane pole alespon jedna chyba. Kdyz neni pole zadane, vraci true pokud je jakakoliv chyba.
     * @param string $fieldName
     * @param bool $throwException Pokud je true, tak v pripade chyby vyhodi vyjimku
     * @return bool
     * @throws RonException
     */
    public function isError($fieldName = null, $throwException = false)
    {
        $error = $this ->findError($fieldName);
        if ($throwException  &&  $error) {
            throw new RonException($error->text, $error->fieldName, $error->description);
        }

        return (bool)$error;
    }


    /**
     * @param Message $message
     * @param int $index
     */
    public static function showMessage($message, $index = null)
    {
        if ($message->type === Message::LOG) {
            echo
                '<script>console.log("DEBUG>", ' .
                ($message->fieldName ? '"' . $message->fieldName . '", ' : '') .
                json_encode(StringUtils::jsonText($message->text, false)) . ');</script>';
        } else {

            $css = isset(self::$TEXT_CLASSES[$message->type]) ? self::$TEXT_CLASSES[$message->type] : null;
            echo
                '<div' . ($css ? " class='$css'" : '') .
                    ($message ->fieldName ? " data-ron-fieldname='{$message ->fieldName}'" : '') .
                    (isset($index) ? " data-ron-index='$index'" : '') .
                    ($message ->id ? " data-ron-id='{$message ->id}'" : '') .
                '>' .
                ($message ->isHtml ? $message ->text : StringUtils::htmlTextConvert($message->text)) .
                "</div>\n";

            if ($message->description) {
                $css = isset(self::$DESCRIPTION_CLASSES[$message->type]) ? self::$DESCRIPTION_CLASSES[$message->type] : null;
                echo '<div' . ($css ? " class='$css'" : '') . '>' . str_replace("\n", '<br/>', StringUtils::htmlTextConvert($message->description)) . "</div>\n";
            }
        }
        //errormsg($message->text, $message->description);
    }


    /**
     * Vraci prvni zpravu, ktera odpovida zadanym podminkam (fieldName a/nebo id)
     * @param string $fieldName
     * @param string $id
     * @return Message
     */
    public function findMessage($fieldName, $id = null)
    {
        foreach ($this->messages as $message) {
            if ((!$fieldName || $message->fieldName == $fieldName) && (!$id || $id == $message->id)) {
                return $message;
            }
        }

        return null;
    }


    /**
     * Zobrazi zpravy pro zadane pole (nebo vsechny, pokud neni zadano), typ a/nebo id.
     * Vraci pocet zobrazenych zprav.
     * @param string|null $fieldname
     * @param string|null $type
     * @param string|null $id
     * @return int
     */
    public function showMessages($fieldname = null, $type = null, $id = null, $deferred = false)
    {
        $index = 0;

        echo '<div class="errormessages">';
        foreach ($this->messages as $message) {
            if (!$fieldname || $message->fieldName == $fieldname) {
                if (!$type || $message->type == $type) {
                    if (!$id || $message->id == $id) {
                        if (!$deferred || $message ->deferred) {
                            self::showMessage($message, $index);
                            $index++;
                        }
                    }
                }
            }
        }
        echo "</div>\n";

        return $index;
    }

    /**
     * Zobrazi chyby pro zadane pole (nebo vsechny, pokud neni zadano).
     * V pripade, ze byla zobrazena alespon jedna chyba vraci false, jinak true
     * @param string|null $fieldname
     * @param string|null $id
     * @return boolean
     */
    function showErrors($fieldname = null, $id = null)
    {
        $cnt = $this->showMessages($fieldname, Message::ERROR, $id);
        return !$cnt;
    }


    public function errorsDialog($htmlId)
    {
        try {
            if (!$this->isError()) {
                return true;
            }
        } catch (RonException $e) {
            echo 'CHYBA v MessageManager::errorsDialog! ' . $e ->getMessage();
        }

        echo "<div class='errorsdialog' id='$htmlId'>";

        foreach ($this->messages as $error) {
            if ($error->type === Message::ERROR) {
                self::showMessage($error);
                //errormsg($error->text, $error->description);
            }
        }

        echo "</div>";

        echo '<script>$( function() { ron.errorsDialog("#' . $htmlId . '")})</script>';
        return false;

    }


    public function storeToSession()
    {
        $array = [];

        foreach ($this->messages as $message) {
            $array[] = $message->storeToArray();
        }

        $_SESSION['Ron.MessageManager.Messages'] = $array;
    }


    protected function loadFromSession()
    {
        $array = isset($_SESSION['Ron.MessageManager.Messages']) ? $_SESSION['Ron.MessageManager.Messages'] : null;

        if ($array) {
            foreach ($array as $msgArray) {
                $message = new Message(Message::INFO);
                $message->loadFromArray($msgArray);

                $this ->addNewMessage($message);
            }

            unset($_SESSION['Ron.MessageManager.Messages']);
        }
    }


    /**
     * Vraci globalni instanci objektu MessageManager
     * @param bool $loadFromSession urcuje, jestli se maji nacist zpravy predane pres session (pouziva se v redirect)
     * @return MessageManager
     */
    public static function getInstance($loadFromSession = true)
    {
        if (!self::$messageManager) {
            self::$messageManager = new MessageManager();

            if ($loadFromSession) {
                self::$messageManager->loadFromSession();
            }
        }

        return self::$messageManager;
    }

    /**
     * @param string $text
     */
    public static function addInfoMessage($text)
    {
        self::getInstance()->addMessage($text);
    }


    /**
     * @param string $text
     */
    public static function addSuccessMessage($text)
    {
        self::getInstance()->addMessage($text, Message::SUCCESS);
    }


    /**
     * @param string|Exception|RonException $text
     * @param string $fieldName
     * @param string $id
     * @param string $description
     * @return bool
     */
    public static function addErrorMessage($text, $fieldName = null, $id = null, $description = null)
    {
        if ($text instanceof DBException) {
            if (!$fieldName) {
                $fieldName = $text ->fieldName;
            }
            $textStr = $text ->getMessage();

            global $development;
            if ($development || App::getDebugMode()) {
                $textStr .= " \n " . $text ->dbMessage;

                if (!$description) {
                    $description = $text ->sql;
                }
            }
        } else if ($text instanceof RonException) {
            if (!$fieldName) {
                $fieldName = $text ->fieldName;
            }
            $textStr = $text ->getMessage();
        } else if ($text instanceof Exception) {
            //if (!App::getDebugMode()) { - PROC?
                $textStr = $text->getMessage();
            //}
        } else {
            $textStr = $text;
        }

        self::getInstance()->addError($textStr, $fieldName, $id, $description);
        return false;
    }


    /**
     * Prida chybovou hlasku, kterou nejdrive prelozi pomoci ronText
     * @param string $textId Kod textu pro preklad
     * @param string $fieldName
     * @param string $id
     * @param string $description
     * @return bool
     */
    public static function addErrorText($textId, $fieldName = null, $id = null, $description = null)
    {
        self::getInstance()->addError(ronText($textId), $fieldName, $id, $description);
        return false;
    }

    /**
     * Prida novou databazovou chybovou hlasku
     * @param Database $database
     * @param string $sql
     * @param string $text
     * @param string $fieldName
     * @return bool
     */
    public static function addDbErrorMessage($database, $sql = null, $text = null, $fieldName = null)
    {
        self::getInstance()->addDbError($database, $sql, $text, $fieldName);
        return false;
    }

    /**
     * @param $text
     * @return null|Message
     */
    public static function addDebugMessage($text)
    {
        if (App::getDebugMode()) {
            return self::getInstance()->addMessage($text, Message::DEBUG);
        }

        return null;
    }

    /**
     * @param $text
     * @param null $fieldName
     * @return null|Message
     */
    public static function addDebugLog($text, $fieldName = null)
    {
        if (App::getDebugMode()) {
            return self::getInstance()->addMessage($text, Message::LOG, $fieldName);
        }

        return null;
    }


    /**
     * Prida hlasku do console.
     * @param string $text
     * @return Message
     */
    public static function addLogMessage($text)
    {
        return self::getInstance()->addMessage($text, Message::LOG);
    }


    public static function debugPost()
    {
        if (App::getDebugMode()) {
            $text = "POST:\n";
            if (is_array($_POST)) {
                foreach ($_POST as $name => $value) {
                    $text .= $name . '=' . $value . "\n";
                }
            }

            return self::addDebugLog($text);
        }

        return null;
    }


    public static function addWarning($text, $fieldName = null, $messageId = null)
    {
        self::getInstance()->addMessage($text, Message::WARNING, $fieldName, $messageId);
    }


    /**
     * Zjisti, jestli existuje nejaka zprava pro zadane pole a podle toho vraci nazev css tridy
     * @param string $fieldName
     * @param string $defaultValue
     * @return string
     */
    public static function getClass($fieldName, $defaultValue = '')
    {
        $result = $defaultValue;

        $mgr = self::getInstance();
        foreach ($mgr->messages as $message) {
            if ($message->fieldName === $fieldName) {
                switch ($message->type) {
                    case Message::ERROR :
                        return 'error';

                    case Message::WARNING :
                        $result = 'warning';
                }
            }
        }

        return $result;
    }

    /**
     * Zjisti, jestli existuje nejaka zprava pro zadane pole a podle toho vraci html kod class="..."
     * @param string $fieldName
     * @param string $defaultClass
     * @return string
     */
    public static function getClassHtml($fieldName, $defaultClass = '')
    {
        $className = self::getClass($fieldName, $defaultClass);
        if ($className) {
            return 'class="' . $className . '"';
        }

        return '';
    }


    /**
     * Zjisti, jestli existuje nejaka zprava pro zadane pole a podle toho vraci title (text chyby)
     * @param string $fieldName
     * @param string $defaultValue
     * @return string
     */
    public static function getTitle($fieldName, $defaultValue = '')
    {
        $result = $defaultValue;

        $mgr = self::getInstance();
        foreach ($mgr->messages as $message) {
            if ($message->fieldName === $fieldName) {
                switch ($message->type) {
                    case Message::ERROR :
                        return $message ->text;

                    case Message::WARNING :
                        $result = $message ->text;
                }
            }
        }

        return $result;
    }


    public static function getTitleHtml($fieldName, $defaultValue = '')
    {
        $title = self::getTitle($fieldName, $defaultValue);
        if ($title) {
            return 'title="' . StringUtils::htmlTextConvert($title) . '"';
        }

        return '';
    }

}
